#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-eval-plugin-2.3.0.0-I8vGmEOOCpcB2XZ8MYKwhN
key:                  hls-eval-plugin-2.3.0.0-I8vGmEOOCpcB2XZ8MYKwhN
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a00b2841f5f7a61925333d31d55af910
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-eval-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.3.0.0-I8vGmEOOCpcB2XZ8MYKwhN
depends:
    Diff-1.0-38Pk9ggjoQQ3bTSUZHJGAf
    QuickCheck-2.15.0.1-5Y9HZXtqNX41xwYMFzmoSZ
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    directory-1.3.8.5 dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX filepath-1.4.300.1 ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghcide-2.3.0.0-ADJYfTGFlXED5XUWhMGPcf
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hls-graph-2.3.0.0-5TnZntcxnjfFOE8vvh0bLs
    hls-plugin-api-2.3.0.0-Jg5s5m9Ajd96ODSU64WGQ6
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
    lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF
    megaparsec-9.7.1-lfMyUtNLhmEXQ4ic9tvxz mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    pretty-simple-4.1.4.0-2GrQ58KNVzoI5vfXzXFEU2
    safe-exceptions-0.1.7.4-Ed9tl0V54XFHH60bY3H5co text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

